#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : zb
# @Time    : 2020/11/15 20:46
# @Blog    : https://blog.zbmain.com
# 个人特殊使用的代码模块使用： __命名（[__类名]（类中变量|函数不需要__））
# __all__ = []
__version__ = '0.0.5'
__author__ = 'zhaobin'
__install__ = 'pip install zbmain'
'''pip install zbmain'''
